scinumtools.structs package
===========================

Submodules
----------

scinumtools.structs.CollectorClass module
-----------------------------------------

.. automodule:: scinumtools.structs.CollectorClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.structs.ParameterClass module
-----------------------------------------

.. automodule:: scinumtools.structs.ParameterClass
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: scinumtools.structs
   :members:
   :undoc-members:
   :show-inheritance:
